JsApiMessage class

Constructors

JsApiMessage(String streamId, dynamic value, String msgType, String reqId, String? url)
JsApiMessage.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
msgType String
getter/setter pair
reqId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId String
getter/setter pair
url String?
getter/setter pair
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited