JsApiService class

Constructors

JsApiService.customJsApi(String assetsJsPath, {String? host, dynamic onErrorCb()?})
JsApiService.dAppInjectedHtml(String html, String? baseUrl, dynamic onErrorCb()?)
JsApiService.reefAppJsApi({dynamic onErrorCb()?})

Properties

API_READY_STREAM_ID String
final
DAPP_MSG_CONFIRMATION_JS_FN_NAME String
final
DAPP_MSG_CONFIRMATION_STREAM_ID String
final
FLUTTER_SUBSCRIBE_METHOD_NAME String
final
flutterJsFilePath → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
jsApiReady Completer<void>
latefinal
jsDAppMsgSubj → BehaviorSubject<JsApiMessage>
final
jsMessageSubj → BehaviorSubject<JsApiMessage>
final
jsMessageUnknownSubj → BehaviorSubject<JsApiMessage>
final
jsTxSignatureConfirmationMessageSubj → BehaviorSubject<JsApiMessage>
final
LOG_STREAM_ID String
final
onJsConnectionError ↔ dynamic Function()?
getter/setter pair
REEF_MOBILE_CHANNEL_NAME String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
TX_SIGN_CONFIRMATION_JS_FN_NAME String
final
TX_SIGNATURE_CONFIRMATION_STREAM_ID String
final

Methods

confirmTxSignature(String reqId, String? mnemonic) → void
jsCall<T>(String executeJs) Future
jsCallVoidReturn(String executeJs) Future<void>
jsObservable(String jsObsRefName) Stream
jsPromise<T>(String jsObsRefName) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectTxSignature(String signatureIdent) → void
sendDappMsgResponse(String reqId, dynamic value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolveBooleanValue(dynamic res) bool