ReefChainApi class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ready
→ Completer<
void> -
final
- reefState → ReefStateApi
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getIndexerConnected(
) → Stream< bool?> -
getProviderConnLogs(
) → Stream< WsConnState?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reconnectProvider(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited