SigningApi class

Constructors

SigningApi(JsApiService _jsApi)

Properties

hashCode int
The hash code for this object.
no setterinherited
jsTxSignatureConfirmationMessageSubj Stream
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bytesString(String bytes) Future
confirmTxSignature(String reqId, String? mnemonic) → void
decodeMethod(String data, {dynamic types}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectTxSignature(String signatureIdent) → void
sendNFT(String unresolvedFrom, String nftContractAddress, String from, String to, int nftAmount, int nftId) Future
signPayload(String address, Map<String, dynamic> payload) Future
signRaw(String address, String message) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited