StatusDataObject<T> class

Constructors

StatusDataObject(T data, List<FeedbackStatus> statusList)

Properties

data ↔ T
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusList List<FeedbackStatus>
getter/setter pair

Methods

hasStatus(StatusCode code, {String? propertyName}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson<T>(dynamic json, ParseFn<T> parsableFn) StatusDataObject<T>?
fromJsonList<T>(dynamic json, ParseListFn<T> parsableListFn) StatusDataObject<List<T>>