SwapApi class

Constructors

SwapApi(JsApiService _jsApi)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPoolReserves(String token1Address, String token2Address) Future
getSwapAmount(String tokenAmount, bool buy, dynamic token1Reserve, dynamic token2Reserve) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
swapTokens(String signerAddress, dynamic mappedToken1, dynamic mappedToken2, dynamic settings) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited