Token class

Implementers

Constructors

Token({required String name, required String address, required String? iconUrl, required String symbol, required BigInt balance, required int decimals})
const

Properties

address String
final
balance BigInt
final
decimals int
final
hashCode int
The hash code for this object.
no setterinherited
iconUrl String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) Token