TokenNFT class

Inheritance

Constructors

TokenNFT({required String name, required dynamic address, required dynamic iconUrl, required dynamic symbol, required dynamic balance, required String nftId, required ContractType contractType, String? mimetype})
const

Properties

address String
finalinherited
balance BigInt
finalinherited
contractType ContractType
final
decimals int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
iconUrl String?
finalinherited
mimetype String?
final
name String
finalinherited
nftId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) TokenNFT
override