TokenActivity class

Constructors

TokenActivity({required DateTime timestamp, required bool isInbound, required String url, Token? token, required String unparsedTimestamp, TokenNFT? tokenNFT})

Properties

extrinsic ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isInbound bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
token Token?
final
tokenNFT TokenNFT?
final
unparsedTimestamp String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) TokenActivity