TokensApi class

Constructors

TokensApi(JsApiService _jsApi)

Properties

hashCode int
The hash code for this object.
no setterinherited
reefPrice$ Stream
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedNFTs_status$ Stream
no setter
selectedTokenPrices_status$ Stream
no setter
selectedTransactionHistory$ Stream
no setter
tokens Stream<StatusDataObject<List<StatusDataObject<TokenWithAmount>>>>
no setter

Methods

findToken(String address) Future
getNftInfo(String nftId, String ownerAddress) Future
getPoolPairs(String tokenAddress) Future
getPools(dynamic offset) Future
getTokenInfo(String tokenAddress) Future
getTxInfo(String timestamp) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reloadTokens() Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited