TransferApi class
Constructors
- TransferApi(JsApiService _jsApi)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transferTokens(
String fromAddress, String toAddress, dynamic token) → Future -
transferTokensStream(
String fromAddress, String toAddress, dynamic token) → Stream
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited