ReefStateApi class
Constructors
- ReefStateApi(JsApiService _jsApi)
Properties
- accountApi ↔ AccountApi
-
latefinal
- contractApi ↔ ContractApi
-
latefinal
- firebaseApi ↔ FirebaseApi
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadataApi ↔ MetadataApi
-
latefinal
- networkApi ↔ NetworkApi
-
latefinal
- poolsApi ↔ PoolsApi
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingApi ↔ SigningApi
-
latefinal
- stealthexApi ↔ StealthexApi
-
latefinal
- swapApi ↔ SwapApi
-
latefinal
- tokenApi ↔ TokensApi
-
latefinal
- transferApi ↔ TransferApi
-
latefinal
Methods
-
init(
ReefNetowrk network, List< ReefAccount> accounts) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited