AccountApi class
Constructors
- AccountApi(JsApiService _jsApi)
Properties
- accountsStatus$ → Stream
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedAddressStream → Stream
-
no setter
Methods
-
accountFromMnemonic(
String mnemonic) → Future< String> -
accountsCreateSuri(
String mnemonic, String password) → Future -
availableAccounts(
) → Stream -
availableSignersStream(
) → Stream -
bindEvmAccount(
String address) → Future -
changeAccountPassword(
String address, String newPass, String oldPass) → Future -
checkMnemonicValid(
String mnemonic) → Future< bool> -
exportAccountQr(
String address, String password) → Future -
formatBalance(
String value, double price, int decimals) → Future< String> -
generateAccount(
) → Future< String> -
isEvmAddressExist(
String address) → Future< bool> -
isValidEvmAddress(
String address) → Future< bool> -
isValidSubstrateAddress(
String address) → Future< bool> -
listenBindActivity(
String address) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveEvmAddress(
String nativeAddress) → Future -
resolveToNativeAddress(
String evmAddress) → Future< String?> -
restoreJson(
Map< String, dynamic> file, String password) → Future -
sanitizeEvmAddress(
String evmAddress) → Future< String> -
setSelectedAddress(
String address) → Future< void> -
toReefEVMAddressNoNotificationString(
String evmAddress) → dynamic -
toReefEVMAddressWithNotificationString(
String evmAddress) → Future -
toString(
) → String -
A string representation of this object.
inherited
-
updateAccounts(
dynamic accounts) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited