TokenWithAmount class
Constructors
- TokenWithAmount({required String name, required dynamic address, required dynamic iconUrl, required dynamic symbol, required dynamic balance, required dynamic decimals, required BigInt amount, required double? price})
-
const
Properties
- address → String
-
finalinherited
- amount → BigInt
-
final
- balance → BigInt
-
finalinherited
- decimals → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconUrl → String?
-
finalinherited
- name → String
-
finalinherited
- price → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAmount(
String newAmount) → TokenWithAmount -
toJsonSkinny(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic json) → TokenWithAmount -
override